/** * This is Ace injected using a bookmarklet. */ function foo() { var bar = true; }
SourceUrl:

# Ace Bookmarklet Builder

WARNING: Currently, this is only supported in non IE browsers.

## How to use it:

- Select the options as you want them to be by default.
- Enter the "SourceUrl". This has to be the URL pointing to build/textarea/src/ (you can leave the default to server the scripts from GitHub).
- Click the "Build Link" button to generate your custom Ace Bookmarklet.
- Drag the generated link to your toolbar or store it somewhere else.
- Go to a page with a textarea element and click the bookmarklet - wait a little bit till the files are loaded.
- Click three times on the textarea you want to replace - Ace will replace it.
- To change settings, just click the red icon in the bottom right corner.